dot-prep_plot_data: Prep Data for Plotting

.prep_plot_dataR Documentation

Prep Data for Plotting

Description

Prep Data for Plotting

Usage

.prep_plot_data(data, idx, ...)

## S3 method for class 'data.frame'
.prep_plot_data(data, idx, ...)

## Default S3 method:
.prep_plot_data(data, idx, name, restricted = "cell", ...)

## S3 method for class 'list'
.prep_plot_data(data, idx, ...)

## S3 method for class ''NULL''
.prep_plot_data(data, idx, ...)

Arguments

data

Extra data for plotting

idx

An rle object where the values are the possible index names and the lengths are the number of times those indexes are present

...

Arguments passed to other methods

name

Name for resulting data.frame

restricted

A vector of names that name should not be

Value

...

Examples

data("pbmc_small")


mojaveazure/ggseurat documentation built on Dec. 10, 2024, 12:05 a.m.